==> sumo_1.1.0+dfsg1.orig.tar.xz: sumo-1.1.0/tools/contributed/lisum-core/src/main/java/de/dlr/ts/lisum/interfaces/ControlUnitInterface.java <==
/****************************************************************************/
// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
// Copyright (C) 2016-2018 German Aerospace Center (DLR) and others.
// This program and the accompanying materials
// are made available under the terms of the Eclipse Public License v2.0
// which accompanies this distribution, and is available at
// http://www.eclipse.org/legal/epl-v20.html
// SPDX-License-Identifier: EPL-2.0
/****************************************************************************/
/// @file    Constants.java
/// @author  Maximiliano Bottazzi
/// @date    2016
/// @version $Id$
///
//
/****************************************************************************/
package de.dlr.ts.lisum.interfaces;

import de.dlr.ts.lisum.enums.LightColor;

/**
 *
 * @author @author <a href="mailto:maximiliano.bottazzi@dlr.de">Maximiliano Bottazzi</a>
 */
public interface ControlUnitInterface
{
    String getFullName();

    int signalGroupsCount();

    LightColor getLightColor(int signalGroupIndex);
    LightColor getLightColor(String signalGroupName);
    
    SignalProgramInterface[] getSignalPrograms();    
    void setCurrentSignalProgram(int index);
    SignalProgramInterface getCurrentSignalProgram();
        
    DetectorInterface getDetector(String name);
    
    boolean isVA();
    void setVA(boolean va);
    
    boolean isIV();
    void setIV(boolean iv);
    
    boolean isOV();
    void setOV(boolean ov);
    
    int getEbene();
    void setEbene(int ebene);
    
    int getKnotenEinAus();
    void setKnotenEinAus(int einAus);
    
    void storePersistent();
    
    void setEnabled(boolean enabled);
    boolean isEnabled();
    
    void setCoordinated(int coordinated);
    int getCoordinated();
    
}

==> sumo_1.4.0+dfsg1.orig.tar.xz: sumo-1_4_0/tools/contributed/lisum-core/src/main/java/de/dlr/ts/lisum/interfaces/ControlUnitInterface.java <==
/****************************************************************************/
// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
// Copyright (C) 2016-2019 German Aerospace Center (DLR) and others.
// This program and the accompanying materials
// are made available under the terms of the Eclipse Public License v2.0
// which accompanies this distribution, and is available at
// http://www.eclipse.org/legal/epl-v20.html
// SPDX-License-Identifier: EPL-2.0
/****************************************************************************/
/// @file    ControlUnitInterface.java
/// @author  Maximiliano Bottazzi
/// @date    2016
///
//
/****************************************************************************/
package de.dlr.ts.lisum.interfaces;

import de.dlr.ts.lisum.enums.LightColor;

/**
 *
 * @author @author <a href="mailto:maximiliano.bottazzi@dlr.de">Maximiliano Bottazzi</a>
 */
public interface ControlUnitInterface {
    String getFullName();

    int signalGroupsCount();

    LightColor getLightColor(int signalGroupIndex);
    LightColor getLightColor(String signalGroupName);

    SignalProgramInterface[] getSignalPrograms();
    void setCurrentSignalProgram(int index);
    SignalProgramInterface getCurrentSignalProgram();

    DetectorInterface getDetector(String name);

    boolean isVA();
    void setVA(boolean va);

    boolean isIV();
    void setIV(boolean iv);

    boolean isOV();
    void setOV(boolean ov);

    int getEbene();
    void setEbene(int ebene);

    int getKnotenEinAus();
    void setKnotenEinAus(int einAus);

    void storePersistent();

    void setEnabled(boolean enabled);
    boolean isEnabled();

    void setCoordinated(int coordinated);
    int getCoordinated();

}
